pub struct SAMLAssertionData {
pub relay_state: String,
pub saml_response: String,
}Expand description
The necessary data, that is sent back from the IdentityProvider to the Service Provider, to complete the authentication
Fields
relay_state: Stringsaml_response: StringTrait Implementations
Sourceimpl Clone for SAMLAssertionData
impl Clone for SAMLAssertionData
Sourcefn clone(&self) -> SAMLAssertionData
fn clone(&self) -> SAMLAssertionData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SAMLAssertionData
impl Debug for SAMLAssertionData
Sourceimpl<'de> Deserialize<'de> for SAMLAssertionData
impl<'de> Deserialize<'de> for SAMLAssertionData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more